# MIRO - DATAWORKBENCH

Personal project

Tools for data analysis

- databox
- ...

## RELEASES

### 0.1.4 2024-03-03

- rename hooks \_init => INIT, \_build BUILD
- add hook `BUILD_METHOD(self, loader, key)`

### 0.1.3 2024-03-02

- Formalize events (allow grey box cache testing)
- Significant tests (enough considering project maturity)

### 0.1.2 2024-03-01

- First Pypi release
